@@ -29,7 +29,7 @@ from pydantic.json import (  # pylint: disable=no-name-in-module
 )
 
 import demessaging.backend.utils as utils
-from demessaging.config import FunctionConfig
+from demessaging.config import FunctionConfig, append_parameter_docs
 
 
 def get_return_model(
@@ -67,7 +67,7 @@ def get_return_model(
 
     field_kws.update(config.returns)
 
-    ret_field = Field(**field_kws)
+    ret_field = Field(**field_kws)  # type: ignore
 
     sig = config.signature
 
@@ -100,6 +100,7 @@ def get_return_model(
     return Model
 
 
+@append_parameter_docs
 class BackendFunctionConfig(FunctionConfig):
     """Configuration class for a backend module function."""
 
@@ -118,6 +119,7 @@ class BackendFunctionConfig(FunctionConfig):
             self.signature = inspect.signature(func)
 
 
+@append_parameter_docs
 class BackendFunction(BaseModel):
     """A base class for a function model.
 
