@@ -90,16 +90,16 @@ def get_fields(
             field_kws.update(config.field_params[key])
 
         if key in config.annotations:
-            fields[key] = (config.annotations[key], Field(**field_kws))
+            fields[key] = (config.annotations[key], Field(**field_kws))  # type: ignore
         elif param.annotation is param.empty:
             warnings.warn(
                 f"Missing signature for {key}, so no validation will "
                 "be made for this parameter!",
                 RuntimeWarning,
             )
-            fields[key] = (Any, Field(**field_kws))
+            fields[key] = (Any, Field(**field_kws))  # type: ignore
         else:
-            fields[key] = (param.annotation, Field(**field_kws))
+            fields[key] = (param.annotation, Field(**field_kws))  # type: ignore
 
         # test for dasf-progress-api reports and add them to the config
         if param.annotation is not param.empty and _is_progress_report(
