@@ -330,6 +330,9 @@ class MessageConsumer(WebsocketConnection):
                     PropertyKeys.REQUEST_CONTEXT
                 ] = MessageConsumer.extract_context(request)
                 response_properties[PropertyKeys.MESSAGE_TYPE] = msg_type
+                response_properties[
+                    PropertyKeys.SOURCE_TOPIC
+                ] = self.pulsar_config.topic
 
                 if response_topic in self.producers:
                     # we already have a producer for this
